@@ -2,7 +2,7 @@
 """
 Main function to setup the daemon process.
 
-Copyright (C) 2011-2013 by Memset Ltd. http://www.memset.com/
+Copyright (C) 2011-2014 by Memset Ltd. http://www.memset.com/
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -111,7 +111,7 @@ class Main(object):
                                   'bind-address': "127.0.0.1",
                                   'port': 8022,
                                   'memcache': None,
-                                  'max-children': 20,
+                                  'max-children': "20",
                                   'log-file': None,
                                   'syslog': 'no',
                                   'verbose': 'no',
@@ -119,6 +119,8 @@ class Main(object):
                                   'pid-file': None,
                                   'uid': None,
                                   'gid': None,
+                                  'split-large-files': "0",
+                                  'hide-part-dir': "no",
                                   # keystone auth 2.0 support
                                   'keystone-auth': False,
                                   'keystone-region-name': None,
@@ -274,7 +276,17 @@ class Main(object):
         if self.pidfile.is_locked():
             parser.error("pid-file found: %s\nIs the server already running?" % options.pid_file)
 
-        options.max_children = config.get('sftpcloudfs', 'max-children')
+        try:
+            options.max_children = int(config.get('sftpcloudfs', 'max-children'))
+        except ValueError:
+            parser.error('max-children: invalid value, integer expected')
+
+        try:
+            options.split_size = int(config.get('sftpcloudfs', 'split-large-files'))*10**6
+        except ValueError:
+            parser.error('split-large-files: invalid size, integer expected')
+
+        options.hide_part_dir = config.getboolean('sftpcloudfs', 'hide-part-dir')
 
         if options.keystone:
             keystone_keys = ('region_name', 'tenant_separator', 'service_type', 'endpoint_type')
@@ -322,6 +334,8 @@ class Main(object):
                                           max_children=self.options.max_children,
                                           keystone=self.options.keystone,
                                           no_scp=self.options.no_scp,
+                                          split_size=self.options.split_size,
+                                          hide_part_dir=self.options.hide_part_dir,
                                           )
 
         dc = daemon.DaemonContext()
